ResolvedFunction

Struct ResolvedFunction 

pub struct ResolvedFunction<'a> {
    pub anchor: u32,
    pub urn: u32,
    pub name: &'a CompoundName,
    pub base_name_unique: bool,
    pub name_unique: bool,
}
The result of resolving a function anchor to its full metadata.

Fields

anchor: u32urn: u32name: &'a CompoundName

The full compound name stored for this anchor.

base_name_unique: bool

true when the base name is unique across all registered functions (controls whether the signature suffix is needed in compact mode).

name_unique: bool

true when the full compound name is unique across all registered functions (controls whether the #anchor suffix is needed).